==> combine-0.1.2.tgz: package/bin/combine.js <==
#! /usr/bin/env node
// 依赖包
var fs = require('fs'), path = require('path'), args = require('arguments');

// 合并文件
var combine = require('../lib/combine').combine;

// 命令参数
var argOpts = {'path': null, 'file': null, 'type': null};

// 帮助函数
function help() {
	var app = path.basename(__filename);
	console.log('Usage: node ' + path.basename(__filename) + ' [options]');
	console.log();
	console.log('Global options:');
	console.log(' --path(-p) <File path>');
	console.log(' --file(-f) <JavaScript file | CSS file>');
	console.log(' --type(-t) <File type>');
	console.log();
	console.log('Example:');
	console.log(' JavaScript');
	console.log('  File: ./test.js');
	console.log('  Usage: node ' + app + ' --path ./ --file test --type js -output test.min.js');
	console.log(' CSS');
	console.log('  File: ./test.css');
	console.log('  Usage: node ' + app + ' --path ./ --file test.css --type css --output test.min.css');
	process.exit();
}
// 入口
function main() {	
	// 解析参数
	args.parse(
		[
			{'name': /^(-h|-help)$/, 'callback': help},
			{'name': /^(--path|-p)$/, 'expected': /^(.*)$/, 'callback': function(cb, val) {argOpts['path'] = val;}},
			{'name': /^(--file|-f)$/, 'expected': /^(.*)$/, 'callback': function(cb, val) {argOpts['file'] = val;}},
			{'name': /^(--type|-t)$/, 'expected': /^(.*)$/, 'callback': function(cb, val) {argOpts['type'] = val;}}
		],
		help,
		function (arg, miss){
			console.log();
			console.log('options: ' + arg + ' is undefined');
			console.log();
			help();
		}
	);
	
	var content = combine(argOpts['path'], argOpts['file'], argOpts['type']);
	console.log(content);
}
main();

==> combine-0.1.3.tgz: package/bin/combine.js <==
#! /usr/bin/env node
// 依赖包
var fs = require('fs'), path = require('path'), args = require('arguments');

// 合并文件
var combine = require('../lib/combine');

// 命令参数
var argOpts = {'path': null, 'file': null, 'type': null};

// 帮助函数
function help() {
	var app = path.basename(__filename);
	console.log('Usage: node ' + path.basename(__filename) + ' [options]');
	console.log();
	console.log('Global options:');
	console.log(' --path(-p) <File path>');
	console.log(' --file(-f) <JavaScript file | CSS file>');
	console.log(' --type(-t) <File type>');
	console.log();
	console.log('Example:');
	console.log(' JavaScript');
	console.log('  File: ./test.js');
	console.log('  Usage: node ' + app + ' --path ./ --file test --type js -output test.combine.js');
	console.log(' CSS');
	console.log('  File: ./test.css');
	console.log('  Usage: node ' + app + ' --path ./ --file test.css --type css --output test.combine.css');
	process.exit();
}
// 入口
function main() {	
	// 解析参数
	args.parse(
		[
			{'name': /^(-h|-help)$/, 'callback': help},
			{'name': /^(--path|-p)$/, 'expected': /^(.*)$/, 'callback': function(cb, val) {argOpts['path'] = val;}},
			{'name': /^(--file|-f)$/, 'expected': /^(.*)$/, 'callback': function(cb, val) {argOpts['file'] = val;}},
			{'name': /^(--type|-t)$/, 'expected': /^(.*)$/, 'callback': function(cb, val) {argOpts['type'] = val;}}
		],
		help,
		function (arg, miss){
			console.log();
			console.log('options: ' + arg + ' is undefined');
			console.log();
			help();
		}
	);
	
	var content = combine(argOpts['path'], argOpts['file'], argOpts['type']);
	console.log(content);
}
main();
